@@ -18,11 +18,12 @@
 # along with datastructures. If not, see <http://www.gnu.org/licenses/>.
 
 
+#' @include methods_peek.R
 #' @include methods_size.R
-#' @include methods_head.R
-#' @include methods_remove.R
+#' @include methods_erase.R
 #' @include methods_clear.R
 
+
 #' @title Map class
 #'
 #' @name map-class
@@ -58,7 +59,7 @@ setClass(
   cat(paste0("An object of class ", clazz, "<",
              object@.key.class, ",T",
              ">\n\n"))
-  li <- head(object)
+  li <- peek(object)
   for (l in names(li))
   {
     e <- li[[l]]
@@ -86,7 +87,7 @@ setClass(
 
 
 #' @noRd
-.remove.map <- function(obj, key)
+.erase.map <- function(obj, key)
 {
     .check.key.class(obj, key)
     obj@.map$remove(key)
@@ -95,11 +96,11 @@ setClass(
 }
 
 
-#' @rdname remove-methods
+#' @rdname erase-methods
 setMethod(
-    "remove",
+    "erase",
     signature = signature(obj = "map", key = "vector", value = "missing"),
-    function(obj, key) .remove.map(obj, key)
+    function(obj, key) .erase.map(obj, key)
 )
 
 
@@ -111,9 +112,10 @@ setMethod("clear", "map", .clear.map)
 setMethod("show", "map", .show.map)
 
 
+#' @rdname peek-methods
+setMethod("peek", "map", .head.map)
+
+
 #' @rdname size-methods
 setMethod("size", "map", .size.map)
 
-
-#' @rdname head-methods
-setMethod("head", "map", .head.map)
